<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Edit Форма Получатели");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Edit Форма Получатели");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "Форма Page");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "Може да зададете повече от един получател чрез отделяне на имейли със запетаи.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Запазване на получател ...");
define('VIEW_FORM_TABLES_HEADING', "Преглед на таблици с формуляри");
define('VIEW_FORM_TABLES_BTN', "Преглед на таблици с формуляри");
define('VIEW_FORM_TABLES_SELECT_TABLE', "Изберете таблици, които да видите");
define('VIEW_FORM_TABLES_FILTER_READ', "Филтриране на четене на съобщения");
?>